@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,10 +31,10 @@ class WP3UnsupportedFixedLengthGroup : public WP3FixedLengthGroup
 {
  public:
 	WP3UnsupportedFixedLengthGroup(WPXInputStream *input, uint8_t groupID);	
-	virtual void parse(WP3Listener *listener) {}
+	void parse(WP3Listener * /* listener */) {}
 	
  protected:
-	virtual void _readContents(WPXInputStream *input) {}
+	void _readContents(WPXInputStream * /* input */) {}
 };
 
 #endif /* WP3UNSUPPORTEDFIXEDLENGTHGROUP_H */
