@@ -1,6 +1,7 @@
 /* libwpd
- * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003-2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2003-2004 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,8 +27,8 @@
 #ifndef WP42FILESTRUCTURE_H
 #define WP42FILESTRUCTURE_H
 
-// size of the functiongroups 0xC0 to 0xFF
-extern int WP42_FUNCTION_GROUP_SIZE[64]; 
+// size of the functiongroups 0xC0 to 0xF8
+extern int WP42_FUNCTION_GROUP_SIZE[63]; 
 
 #define WP42_ATTRIBUTE_BOLD 0
 #define WP42_ATTRIBUTE_ITALICS 1
@@ -36,4 +37,13 @@ extern int WP42_FUNCTION_GROUP_SIZE[64];
 #define WP42_ATTRIBUTE_SHADOW 4
 #define WP42_ATTRIBUTE_REDLINE 5
 
+#define WP42_MARGIN_RESET_GROUP 0xC0
+
+#define WP42_SUPPRESS_PAGE_CHARACTERISTICS_GROUP 0xCF
+
+#define WP42_HEADER_FOOTER_GROUP 0xD1
+#define WP42_HEADER_FOOTER_GROUP_ALL_BIT 1
+#define WP42_HEADER_FOOTER_GROUP_ODD_BIT 2
+#define WP42_HEADER_FOOTER_GROUP_EVEN_BIT 4
+
 #endif /* WP42FILESTRUCTURE_H */
