@@ -1,6 +1,8 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2007 Fridrich Strba (fridrich.strba@bluewin.ch)
+ * Copyright (C) 2007 Novell, Inc. (http://www.novell.com)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,14 +29,15 @@
 #define WP5PAGEFORMATGROUP_H
 
 #include "WP5VariableLengthGroup.h"
+#include <vector>
 
 class WP5PageFormatGroup : public WP5VariableLengthGroup
 {
  public:
 	WP5PageFormatGroup(WPXInputStream *input);	
-	virtual ~WP5PageFormatGroup();
-	virtual void _readContents(WPXInputStream *input);
-	virtual void parse(WP5Listener *listener);
+	~WP5PageFormatGroup();
+	void _readContents(WPXInputStream *input);
+	void parse(WP5Listener *listener);
 
  private:
 	// variables needed for subgroup 1 (Left/Right Margin Set)
@@ -42,11 +45,16 @@ class WP5PageFormatGroup : public WP5VariableLengthGroup
 	uint16_t m_rightMargin;
 	// variable needed for subgroup 2 (Spacing Set)
 	float m_lineSpacing;
+	// variables needed for subbroup 4 (Tab Set)
+	std::vector<WPXTabStop> m_tabStops;
+	uint16_t m_marginOffset;	
 	// variables needed for subgroup 5 (Top/Bottom Margin Set)
 	uint16_t m_topMargin;
 	uint16_t m_bottomMargin;
 	// variables needed for subgroup 6 (Justification)
 	uint8_t m_justification;
+	// variable needed for subgroup 7 (Suppress Page Characteristics)
+	uint8_t m_suppressCode;
 	// variables needed for subgroup 11 (Form)
 	uint16_t m_formLength;
 	uint16_t m_formWidth;
