@@ -38,7 +38,7 @@ public:
 	WP6FillStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
 	~WP6FillStylePacket();
 	void _readContents(WPXInputStream *input);
-	void parse(WP6Listener *listener) const {}
+	void parse(WP6Listener * /* listener */) const {}
 	const RGBSColor * getFgColor() const { return &m_fgColor; }
 	const RGBSColor * getBgColor() const { return &m_bgColor; }
 private:              
