@@ -1,6 +1,7 @@
 /* libwpd
  * Copyright (C) 2004 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2005 Net Integration Technologies (http://www.net-itech.com)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -28,9 +29,13 @@
 
 #include <string>
 #include <stdarg.h>
-//#include <string.h>
 #include <stdio.h>
 
+#define FIRST_BUF_SIZE 128
+#ifdef _MSC_VER
+#define vsnprintf _vsnprintf
+#endif
+
 static int g_static_utf8_strlen (const char *p);
 static int g_static_unichar_to_utf8 (uint32_t c,  char *outbuf);
 
@@ -53,30 +58,39 @@ static const int8_t g_static_utf8_skip_data[256] = {
       ((Char) < 0x4000000 ? 5 : 6)))))
 #define g_static_utf8_next_char(p) (char *)((p) + g_static_utf8_skip_data[*((uint8_t *)p)])
 
+class WPXStringImpl
+{
+public:
+	WPXStringImpl() : m_buf() {}
+	std::string m_buf;
+};
+
 WPXString::~WPXString()
 {
-	delete static_cast<std::string*>(m_buf);
+	delete m_stringImpl;
 }
 
-WPXString::WPXString()
+WPXString::WPXString() :
+	m_stringImpl(new WPXStringImpl)
 {
-	m_buf = static_cast<void *>(new std::string());
+	m_stringImpl->m_buf.reserve(FIRST_BUF_SIZE);
 }
 
-WPXString::WPXString(const WPXString &stringBuf)
+WPXString::WPXString(const WPXString &stringBuf) :
+	m_stringImpl(new WPXStringImpl)
 {
-	m_buf = static_cast<void *>(new std::string(*static_cast<std::string*>(stringBuf.m_buf)));
+	m_stringImpl->m_buf = stringBuf.m_stringImpl->m_buf;
 }
 
-WPXString::WPXString(const WPXString &stringBuf, bool escapeXML) 
+WPXString::WPXString(const WPXString &stringBuf, bool escapeXML) :
+	m_stringImpl(new WPXStringImpl) 
 {
-
 	if (escapeXML)
 	{
-		m_buf = static_cast<void *>(new std::string());
-		int len = static_cast<std::string*>(stringBuf.m_buf)->length(); // strlen(stringBuf.cstr()); // want to use standard strlen
+		int tmpLen = stringBuf.m_stringImpl->m_buf.length();
+		m_stringImpl->m_buf.reserve(2*tmpLen);
 		const char *p = stringBuf.cstr();
-		const char *end = p + len; 
+		const char *end = p + tmpLen; 
 		while (p != end)
 		{
 			const char *next = g_static_utf8_next_char(p);
@@ -111,34 +125,30 @@ WPXString::WPXString(const WPXString &stringBuf, bool escapeXML)
 		}
 	}
 	else
-		m_buf = static_cast<void *>(new std::string(*static_cast<std::string*>(stringBuf.m_buf)));
+		m_stringImpl->m_buf = stringBuf.m_stringImpl->m_buf;
 }
 
-WPXString::WPXString(const char *str)
+WPXString::WPXString(const char *str) :
+	m_stringImpl(new WPXStringImpl)
 {
-	m_buf = static_cast<void *>(new std::string(str));
+	m_stringImpl->m_buf = std::string(str);
 }
 
 const char * WPXString::cstr() const
 {
-    return static_cast<std::string *>(m_buf)->c_str();
+    return m_stringImpl->m_buf.c_str();
 }
 
-#define FIRST_BUF_SIZE 128;
-#ifdef _MSC_VER
-#define vsnprintf _vsnprintf
-#endif
-
 void WPXString::sprintf(const char *format, ...)
 {
 	va_list args;
 
 	int bufsize = FIRST_BUF_SIZE;
-	char * buf = NULL;
+	char firstBuffer[FIRST_BUF_SIZE];
+	char * buf = firstBuffer;
 
 	while(true)
 	{
-			buf = new char[bufsize];
 			va_start(args, format);
 			int outsize = vsnprintf(buf, bufsize, format, args);
 			va_end(args);
@@ -150,32 +160,37 @@ void WPXString::sprintf(const char *format, ...)
 			else
 				break;
 
-			delete [] buf;
+			if (buf != firstBuffer)
+			{
+				delete [] buf;
+				buf = new char[bufsize];
+			}
 	}
 
 	clear();
 	append(buf);
-	delete [] buf;
+	if (buf != firstBuffer)
+		delete [] buf;
 }
 
 void WPXString::append(const WPXString &s)
 {
-	static_cast<std::string *>(m_buf)->append(*static_cast<std::string*>(s.m_buf));
+	m_stringImpl->m_buf.append(s.m_stringImpl->m_buf);
 }
 
 void WPXString::append(const char *s)
 {
-	static_cast<std::string *>(m_buf)->append(s);
+	m_stringImpl->m_buf.append(s);
 }
 
 void WPXString::append(const char c)
 {
-	*(static_cast<std::string *>(m_buf)) += c;
+	m_stringImpl->m_buf.append(1, c);
 }
 
 void WPXString::clear()
 {
-	static_cast<std::string *>(m_buf)->erase(static_cast<std::string *>(m_buf)->begin(), static_cast<std::string *>(m_buf)->end());
+	m_stringImpl->m_buf.erase(m_stringImpl->m_buf.begin(), m_stringImpl->m_buf.end());
 }
 
 int WPXString::len() const
@@ -185,32 +200,32 @@ int WPXString::len() const
 
 WPXString& WPXString::operator=(const WPXString &stringBuf)
 {
-	*static_cast<std::string*>(m_buf) = *static_cast<std::string*>(stringBuf.m_buf);
+	m_stringImpl->m_buf = stringBuf.m_stringImpl->m_buf;
 	return *this;
 }
 
 bool WPXString::operator==(const char *str)
 {
-	return (*static_cast<std::string*>(m_buf) == str);
+	return (m_stringImpl->m_buf == str);
 }
 
 bool WPXString::operator==(const WPXString &str)
 {
-	return (*static_cast<std::string*>(m_buf) == *static_cast<std::string*>(str.m_buf));
+	return (m_stringImpl->m_buf == str.m_stringImpl->m_buf);
 }
 
 WPXString::Iter::Iter(const WPXString &str) :
+	m_stringImpl(new WPXStringImpl),
 	m_pos(0),
-	m_curChar(NULL)
+	m_curChar(0)
 {
-	m_buf = static_cast<void *>(new std::string(str.cstr()));
-
+	m_stringImpl->m_buf = str.cstr();
 }
 
 WPXString::Iter::~Iter()
 {
 	delete [] m_curChar;
-	delete (static_cast<std::string *>(m_buf));
+	delete m_stringImpl;
 }
 
 void WPXString::Iter::rewind()
@@ -220,14 +235,14 @@ void WPXString::Iter::rewind()
 
 bool WPXString::Iter::next()
 {
-	int len = static_cast<std::string *>(m_buf)->length();
+	int len = m_stringImpl->m_buf.length();
 
 	if (m_pos == (-1)) 
 		m_pos++;
 	else if (m_pos < len)
 	{
-		m_pos+=(int32_t) (g_static_utf8_next_char(&(static_cast<std::string *>(m_buf)->c_str()[m_pos])) - 
-				  &(static_cast<std::string *>(m_buf)->c_str()[m_pos]));
+		m_pos+=(int32_t) (g_static_utf8_next_char(&(m_stringImpl->m_buf.c_str()[m_pos])) - 
+				  &(m_stringImpl->m_buf.c_str()[m_pos]));
 	}
 
 	if (m_pos < len)
@@ -237,21 +252,21 @@ bool WPXString::Iter::next()
 
 bool WPXString::Iter::last()
 {
-	if (m_pos >= g_static_utf8_strlen(static_cast<std::string *>(m_buf)->c_str()))
+	if (m_pos >= g_static_utf8_strlen(m_stringImpl->m_buf.c_str()))
 		return true;
 	return false;
 }
 
 const char * WPXString::Iter::operator()() const
 { 
-	if (m_pos == (-1)) return NULL; 
+	if (m_pos == (-1)) return 0; 
 
-	delete [] m_curChar; m_curChar = NULL;
-	int32_t charLength =(int32_t) (g_static_utf8_next_char(&(static_cast<std::string *>(m_buf)->c_str()[m_pos])) - 
-				       &(static_cast<std::string *>(m_buf)->c_str()[m_pos]));
+	if (m_curChar) delete [] m_curChar; m_curChar = 0;
+	int32_t charLength =(int32_t) (g_static_utf8_next_char(&(m_stringImpl->m_buf.c_str()[m_pos])) - 
+				       &(m_stringImpl->m_buf.c_str()[m_pos]));
 	m_curChar = new char[charLength+1];
 	for (int i=0; i<charLength; i++)
-		m_curChar[i] = (*(static_cast<std::string *>(m_buf)))[m_pos+i];
+		m_curChar[i] = m_stringImpl->m_buf[m_pos+i];
 	m_curChar[charLength]='\0';
 
 	return m_curChar;
@@ -261,8 +276,8 @@ const char * WPXString::Iter::operator()() const
 
 void appendUCS4(WPXString &str, uint32_t ucs4)
 {
-	int charLength = g_static_unichar_to_utf8(ucs4, NULL);
-	char *utf8 = new(char[charLength+1]);
+	int charLength = g_static_unichar_to_utf8(ucs4, 0);
+	char *utf8 = new char[charLength+1];
 	utf8[charLength] = '\0';
 	g_static_unichar_to_utf8(ucs4, utf8);
 	str.append(utf8);
@@ -270,27 +285,26 @@ void appendUCS4(WPXString &str, uint32_t ucs4)
 	delete[] utf8;
 }
 
-/**
+/*
  * g_static_unichar_to_utf8:
  *
  * stolen from glib 2.4.1
  *
  * @c: a ISO10646 character code
  * @outbuf: output buffer, must have at least 6 bytes of space.
- *       If %NULL, the length will be computed and returned
+ *       If %0, the length will be computed and returned
  *       and nothing will be written to @outbuf.
  * 
  * Converts a single character to UTF-8.
  * 
  * Return value: number of bytes written
- **/
+ */
 int
 g_static_unichar_to_utf8 (uint32_t c,
 			  char   *outbuf)
 {
-	unsigned int len = 0;    
-	int first;
-	int i;
+	uint8_t len = 1;    
+	uint8_t first = 0;
     
 	if (c < 0x80)
 	{
@@ -325,31 +339,30 @@ g_static_unichar_to_utf8 (uint32_t c,
     
 	if (outbuf)
 	{
-		for (i = len - 1; i > 0; --i)
+		for (uint8_t i = len - 1; i > 0; --i)
 		{
-			outbuf[i] = (c & 0x3f) | 0x80;
+			outbuf[i] = (char)((c & 0x3f) | 0x80);
 			c >>= 6;
 		}
-		outbuf[0] = c | first;
+		outbuf[0] = (char)(c | first);
 	}
     
 	return len;
 }
 
-/**
+/*
  * g_static_utf8_strlen:
  * @p: pointer to the start of a UTF-8 encoded string.
-
  * 
  * Returns the length of the string in characters.
  *
  * Return value: the length of the string in characters
- **/
+ */
 int
 g_static_utf8_strlen (const char *p)
 {
 	long len = 0;
-	if (p == NULL)
+	if (!p)
 		return 0;
 
 	while (*p)
